--AH:ScriptId=4b68b2ab-3af6-45a9-809e-932eab3e422f;2887
CREATE TABLE [MavenArtifacts]
(
	[MavenArtifact_Id] INT IDENTITY(1,1) NOT NULL,
	[Feed_Id] INT NOT NULL,
	[GroupId_Text] NVARCHAR(200) NOT NULL,
	[ArtifactId_Text] NVARCHAR(100) NOT NULL,
	[Name_Text] NVARCHAR(50) NULL,
	[Description_Text] VARBINARY(MAX) NULL,
	[ReleaseVersion_Text] NVARCHAR(50) NULL,
	[LatestVersion_Text] NVARCHAR(50) NOT NULL,

	CONSTRAINT [UQ__MavenArtifacts]
		UNIQUE CLUSTERED ([Feed_Id], [GroupId_Text], [ArtifactId_Text]),

	CONSTRAINT [PK__MavenArtifacts]
		PRIMARY KEY ([MavenArtifact_Id]),

	CONSTRAINT [FK__MavenArtifacts__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id]),

	CONSTRAINT [CK__MavenArtifacts__GroupId_Text]
		CHECK ([GroupId_Text] <> ''),

	CONSTRAINT [CK__MavenArtifacts__ArtifactId_Text]
		CHECK ([ArtifactId_Text] <> '')
)

CREATE TABLE [MavenArtifactFiles]
(
	[MavenArtifact_Id] INT NOT NULL,
	[Version_Text] NVARCHAR(50) NOT NULL,
	[File_Type] NVARCHAR(20) NOT NULL,
	[File_SHA1_Bytes] BINARY(20) NOT NULL,
	[File_MD5_Bytes] BINARY(16) NOT NULL,
	[File_Size] BIGINT NOT NULL,
	[Updated_Date] DATETIME NOT NULL,
	[Cached_Indicator] YNINDICATOR NOT NULL,
	[Download_Count] INT NOT NULL,

	CONSTRAINT [PK__MavenArtifactFiles]
		PRIMARY KEY ([MavenArtifact_Id], [Version_Text], [File_Type]),

	CONSTRAINT [FK__MavenArtifactFiles__MavenArtifacts]
		FOREIGN KEY ([MavenArtifact_Id])
		REFERENCES [MavenArtifacts] ([MavenArtifact_Id]),

	CONSTRAINT [CK__MavenArtifacts__Version_Text]
		CHECK ([Version_Text] <> ''),

	CONSTRAINT [CK__MavenArtifactFiles__File_Size]
		CHECK ([File_Size] >= 0),

	CONSTRAINT [CK__MavenArtifactFiles__Download_Count]
		CHECK ([Download_Count] >= 0)
)

CREATE TABLE [MavenConnectors]
(
	[MavenConnector_Id] INT IDENTITY(1,1) NOT NULL,
	[Repository_Url] VARCHAR(500) NOT NULL,
	[LastUpdated_Date] DATETIME NULL,
	[IndexingStatus_Percent] INT NULL,
	[IndexingLog_Text] VARBINARY(MAX) NULL,
	[UserName_Bytes] VARBINARY(200) NULL,
	[Password_Bytes] VARBINARY(200) NULL,
	[Timeout_Period] INT NOT NULL,

	CONSTRAINT [PK__MavenConnectors]
		PRIMARY KEY ([MavenConnector_Id]),

	CONSTRAINT [UQ__MavenConnectors]
		UNIQUE ([Repository_Url]),

	CONSTRAINT [CK__MavenConnectors__Repository_Url]
		CHECK (([Repository_Url] LIKE 'http://_%') OR ([Repository_Url] LIKE 'https://_%')),

	CONSTRAINT [CK__MavenConnectors__IndexingStatus_Percent]
		CHECK ([IndexingStatus_Percent] IS NULL OR ([IndexingStatus_Percent] >= 0 AND [IndexingStatus_Percent] <= 100)),

	CONSTRAINT [CK__MavenConnectors__Password_Bytes]
		CHECK ([Password_Bytes] IS NULL OR [UserName_Bytes] IS NOT NULL),

	CONSTRAINT [CK__MavenConnectors__Timeout_Period]
		CHECK ([Timeout_Period] >= 0)
)

CREATE TABLE [MavenFeedConnectors]
(
	[Feed_Id] INT NOT NULL,
	[MavenConnector_Id] INT NOT NULL,
	[Filter_Csv] NVARCHAR(1000) NULL,

	CONSTRAINT [PK__MavenFeedConnectors]
		PRIMARY KEY ([Feed_Id], [MavenConnector_Id]),

	CONSTRAINT [FK__MavenFeedConnectors__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id]),

	CONSTRAINT [FK__MavenFeedConnectors__MavenConnectors]
		FOREIGN KEY ([MavenConnector_Id])
		REFERENCES [MavenConnectors] ([MavenConnector_Id])
)

CREATE TABLE [MavenFeeds]
(
	[Feed_Id] INT NOT NULL,
	[IndexUpdateFrequency_Days] INT NULL,
	[IndexUpdateWindowStart_Hours] INT NOT NULL,
	[IndexUpdateWindowEnd_Hours] INT NOT NULL,
	[LastIndexUpdate_Date] DATETIME NULL,
	[LastIndexUpdateDuration_Seconds] INT NULL,
	[LastIndexUpdateLog_Text] VARBINARY(MAX),
	[UpdateImmediately_Indicator] YNINDICATOR NOT NULL,

	CONSTRAINT [PK__MavenFeeds]
		PRIMARY KEY ([Feed_Id]),

	CONSTRAINT [FK__MavenFeeds__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id]),

	CONSTRAINT [CK__MavenFeeds__IndexUpdateFrequency_Days]
		CHECK ([IndexUpdateFrequency_Days] IS NULL OR [IndexUpdateFrequency_Days] > 0),

	CONSTRAINT [CK__MavenFeeds__IndexUpdateWindowStart_Hours]
		CHECK ([IndexUpdateWindowStart_Hours] >= 0 AND [IndexUpdateWindowStart_Hours] <= 23),

	CONSTRAINT [CK__MavenFeeds__IndexUpdateWindowEnd_Hours]
		CHECK ([IndexUpdateWindowEnd_Hours] >= 0 AND [IndexUpdateWIndowEnd_Hours] <= 23),

	CONSTRAINT [CK__MavenFeeds__LastIndexUpdateDuration_Seconds]
		CHECK ([LastIndexUpdateDuration_Seconds] IS NULL OR [LastIndexUpdateDuration_Seconds] >= 0)
)