EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ContainerUsage_GetUsageByFeed',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'ContainerUsage',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets usage information for the specified container image.'
GO

IF OBJECT_ID('[ContainerUsage_GetUsageByFeed]') IS NOT NULL DROP PROCEDURE [ContainerUsage_GetUsageByFeed]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ContainerUsage_GetUsageByFeed]
(
	@Feed_Id INT
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT CU.[Container_Id]
      ,CU.[PackageContainerScanner_Id]
      ,CU.[Server_Name]
      ,[Container_Name] = DI.[Repository_Name]  -- for linking purposes
      ,CU.[Image_Id]
      ,CU.[Details_Url]
      ,CU.[ContainerStatus_Code]
      ,CU.[Updated_Date]
      ,CU.[Created_Date]
	  FROM [ContainerUsage] CU
	       INNER JOIN [FeedPackageContainerScanners] FPCS
		           ON FPCS.[PackageContainerScanner_Id] = CU.[PackageContainerScanner_Id]
	INNER JOIN [DockerImages_Extended] DI
		ON DI.[ContainerConfigBlob_Digest] = CU.[Image_Id] OR DI.[Image_Digest] = CU.[Image_Id]
	 WHERE FPCS.[Feed_Id] = @Feed_Id AND DI.[Feed_Id] = @Feed_Id
	 ORDER BY DI.Download_Count DESC

END
GO

GRANT EXECUTE ON [ContainerUsage_GetUsageByFeed] TO [ProGetUser_Role]
GO