EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_CreateTag',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a tag.'
GO

IF OBJECT_ID('[DockerImages_CreateTag]') IS NOT NULL DROP PROCEDURE [DockerImages_CreateTag]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_CreateTag]
(
    -- should be DockerImages_CreateTag, and take @DockerImage_Id and @Tag_Name Only; to "set" a tag, we can delete/create from front-end
	@DockerImage_Id INT,
	@Tag_Name VARCHAR(255),
	@Comments_Text NVARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION
	
	DECLARE @DockerRepository_Id INT
	SELECT @DockerRepository_Id = [DockerRepository_Id]
	  FROM [DockerImages]
     WHERE [DockerImage_Id] = @DockerImage_Id

	INSERT INTO [DockerRepositoryTags]
	(
		[DockerRepository_Id],
		[Tag_Name],
		[DockerImage_Id],
		[CreatedBy_User_Name],
		[Created_Date],
		[Comments_Text]
	)
	VALUES
	(
		@DockerRepository_Id,
		@Tag_Name,
		@DockerImage_Id,
		dbo.Session_GetUserName(),
		GETUTCDATE(),
		@Comments_Text
	)
	COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_CreateTag] TO [ProGetUser_Role]
GO