EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ProGetLicensingViolations_RecordViolation',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records a license violation entry.'
GO

IF OBJECT_ID('[ProGetLicensingViolations_RecordViolation]') IS NOT NULL DROP PROCEDURE [ProGetLicensingViolations_RecordViolation]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ProGetLicensingViolations_RecordViolation]
(	
	@Feed_Id INT,
	@Connector_Id INT,
	@Lookup_Hash BINARY(32),
    @ConnectedTo_Url NVARCHAR(MAX),
    @ConnectedFrom_IP VARCHAR(200),
    @ConnectedFrom_UserAgent NVARCHAR(200)
)
AS
BEGIN

	IF EXISTS(SELECT * FROM [ProGetLicensingViolations] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Lookup_Hash] = @Lookup_Hash)

		UPDATE [ProGetLicensingViolations]
		   SET [Connector_Id] = @Connector_Id,
		       [ConnectedTo_Url] = @ConnectedTo_Url,
			   [ConnectedFrom_UserAgent] = @ConnectedFrom_UserAgent,
			   [LastModified_Date] = GETUTCDATE(),
			   [Violation_Count] = [Violation_Count] + 1
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Lookup_Hash] = @Lookup_Hash

	ELSE

		INSERT INTO [ProGetLicensingViolations]
		(
			[Feed_Id],
			[Connector_Id],
			[Lookup_Hash],
			[ConnectedTo_Url],
			[ConnectedFrom_IP],
			[ConnectedFrom_UserAgent],
			[LastModified_Date],
			[Violation_Count]
		)
		VALUES
		(
			@Feed_Id,
			@Connector_Id,
			@Lookup_Hash,
			@ConnectedTo_Url,
			@ConnectedFrom_IP,
			@ConnectedFrom_UserAgent,
			GETUTCDATE(),
			1
		)

END
GO

GRANT EXECUTE ON [ProGetLicensingViolations_RecordViolation] TO [ProGetUser_Role]
GO