EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ReplicationClients_CreateOrUpdateEntry',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records information from a replication client when it performs a feed state check.'
GO

IF OBJECT_ID('[ReplicationClients_CreateOrUpdateEntry]') IS NOT NULL DROP PROCEDURE [ReplicationClients_CreateOrUpdateEntry]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ReplicationClients_CreateOrUpdateEntry]
(
	@Feed_Id INT,
	@IPAddress_Text VARCHAR(50),
	@Client_Name VARCHAR(50),
	@UserAgent_Text VARCHAR(50),
	@Error_Indicator YNINDICATOR,
	@Status_Text NVARCHAR(MAX),
	@LastEvent_Text NVARCHAR(MAX) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ReplicationClient_Id INT
	SET @ReplicationClient_Id = (SELECT [ReplicationClient_Id] FROM [ReplicationClients] WHERE [Feed_Id] = @Feed_Id AND [IPAddress_Text] = @IPAddress_Text)

	IF @ReplicationClient_Id IS NULL

		INSERT INTO [ReplicationClients]
		(
			[Feed_Id],
			[LastConnection_Date],
			[IPAddress_Text],
			[Client_Name],
			[UserAgent_Text],
			[Error_Indicator],
			[Status_Text],
			[LastEvent_Text],
			[LastEvent_Date]
		)
		VALUES
		(
			@Feed_Id,
			GETUTCDATE(),
			@IPAddress_Text,
			@Client_Name,
			@UserAgent_Text,
			@Error_Indicator,
			@Status_Text,
			@LastEvent_Text,
			CASE WHEN @LastEvent_Text IS NOT NULL THEN GETUTCDATE() ELSE NULL END
		)

	ELSE

		UPDATE [ReplicationClients]
		   SET [LastConnection_Date] = GETUTCDATE(),
		       [Client_Name] = @Client_Name,
			   [UserAgent_Text] = COALESCE(@UserAgent_Text, [UserAgent_Text]),
			   [Error_Indicator] = @Error_Indicator,
			   [Status_Text] = @Status_Text,
			   [LastEvent_Text] = COALESCE(@LastEvent_Text, [LastEvent_Text]),
			   [LastEvent_Date] = CASE WHEN @LastEvent_Text IS NOT NULL THEN GETUTCDATE() ELSE [LastEvent_Date] END
		 WHERE [ReplicationClient_Id] = @ReplicationClient_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ReplicationClients_CreateOrUpdateEntry] TO [ProGetUser_Role]
GO
